==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/authpgsql/lang/sk/settings.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Martin Michalek <michalek.dev@gmail.com>
 */
$lang['server']                = 'PostgreSQL server';
$lang['port']                  = 'Port PostgreSQL servera';
$lang['user']                  = 'Meno používateľa PostgreSQL';
$lang['password']              = 'Heslo pre vyššie uvedeného používateľa';
$lang['database']              = 'Použiť databázu';
$lang['debug']                 = 'Zobraziť doplňujúce ladiace informácie';
$lang['forwardClearPass']      = 'Posielať heslo ako nezakódovaný text nižšie uvedenému SQL príkazu namiesto použitia kódovania';
$lang['checkPass']             = 'SQL príkaz pre kontrolu hesla';
$lang['getUserInfo']           = 'SQL príkaz pre získanie informácií o používateľovi';
$lang['getGroups']             = 'SQL príkaz pre získanie informácií o skupinách používateľa';
$lang['getUsers']              = 'SQL príkaz pre získanie zoznamu používateľov';
$lang['FilterLogin']           = 'SQL podmienka pre filtrovanie používateľov podľa prihlasovacieho mena';
$lang['FilterName']            = 'SQL podmienka pre filtrovanie používateľov podľa mena a priezviska';
$lang['FilterEmail']           = 'SQL podmienka pre filtrovanie používateľov podľa emailovej adresy';
$lang['FilterGroup']           = 'SQL podmienka pre filtrovanie používateľov podľa skupiny';
$lang['SortOrder']             = 'SQL podmienka pre usporiadenia používateľov';
$lang['addUser']               = 'SQL príkaz pre pridanie nového používateľa';
$lang['addGroup']              = 'SQL príkaz pre pridanie novej skupiny';
$lang['addUserGroup']          = 'SQL príkaz pre pridanie používateľa do existujúcej skupiny';
$lang['delGroup']              = 'SQL príkaz pre zrušenie skupiny';
$lang['getUserID']             = 'SQL príkaz pre získanie primárneho klúča používateľa';
$lang['delUser']               = 'SQL príkaz pre zrušenie používateľa';
$lang['delUserRefs']           = 'SQL príkaz pre vyradenie používateľa zo všetkých skupín';
$lang['updateUser']            = 'SQL príkaz pre aktualizáciu informácií o používateľovi';
$lang['UpdateLogin']           = 'SQL podmienka pre aktualizáciu prihlasovacieho mena používateľa';
$lang['UpdatePass']            = 'SQL podmienka pre aktualizáciu hesla používateľa';
$lang['UpdateEmail']           = 'SQL podmienka pre aktualizáciu emailovej adresy používateľa';
$lang['UpdateName']            = 'SQL podmienka pre aktualizáciu mena a priezviska používateľa';
$lang['UpdateTarget']          = 'Podmienka identifikácie používateľa pri aktualizácii';
$lang['delUserGroup']          = 'SQL príkaz pre vyradenie používateľa z danej skupiny';
$lang['getGroupID']            = 'SQL príkaz pre získanie primárneho kľúča skupiny';

==> dokuwiki_0.0.20160626.a.orig.tar.gz: dokuwiki-2016-06-26a/lib/plugins/authpgsql/lang/sk/settings.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Martin Michalek <michalek.dev@gmail.com>
 */
$lang['server']                = 'PostgreSQL server';
$lang['port']                  = 'Port PostgreSQL servera';
$lang['user']                  = 'Meno používateľa PostgreSQL';
$lang['password']              = 'Heslo pre vyššie uvedeného používateľa';
$lang['database']              = 'Použiť databázu';
$lang['debug']                 = 'Zobraziť dodatočné ladiace informácie';
$lang['forwardClearPass']      = 'Posielať heslo ako nezakódovaný text nižšie uvedenému SQL príkazu namiesto použitia kódovania';
$lang['checkPass']             = 'SQL príkaz pre kontrolu hesla';
$lang['getUserInfo']           = 'SQL príkaz pre získanie informácií o používateľovi';
$lang['getGroups']             = 'SQL príkaz pre získanie informácií o skupinách používateľa';
$lang['getUsers']              = 'SQL príkaz pre získanie zoznamu používateľov';
$lang['FilterLogin']           = 'SQL podmienka pre filtrovanie používateľov podľa prihlasovacieho mena';
$lang['FilterName']            = 'SQL podmienka pre filtrovanie používateľov podľa mena a priezviska';
$lang['FilterEmail']           = 'SQL podmienka pre filtrovanie používateľov podľa emailovej adresy';
$lang['FilterGroup']           = 'SQL podmienka pre filtrovanie používateľov podľa skupiny';
$lang['SortOrder']             = 'SQL podmienka pre usporiadenia používateľov';
$lang['addUser']               = 'SQL príkaz pre pridanie nového používateľa';
$lang['addGroup']              = 'SQL príkaz pre pridanie novej skupiny';
$lang['addUserGroup']          = 'SQL príkaz pre pridanie používateľa do existujúcej skupiny';
$lang['delGroup']              = 'SQL príkaz pre zrušenie skupiny';
$lang['getUserID']             = 'SQL príkaz pre získanie primárneho klúča používateľa';
$lang['delUser']               = 'SQL príkaz pre zrušenie používateľa';
$lang['delUserRefs']           = 'SQL príkaz pre vyradenie používateľa zo všetkých skupín';
$lang['updateUser']            = 'SQL príkaz pre aktualizáciu informácií o používateľovi';
$lang['UpdateLogin']           = 'SQL podmienka pre aktualizáciu prihlasovacieho mena používateľa';
$lang['UpdatePass']            = 'SQL podmienka pre aktualizáciu hesla používateľa';
$lang['UpdateEmail']           = 'SQL podmienka pre aktualizáciu emailovej adresy používateľa';
$lang['UpdateName']            = 'SQL podmienka pre aktualizáciu mena a priezviska používateľa';
$lang['UpdateTarget']          = 'Podmienka identifikácie používateľa pri aktualizácii';
$lang['delUserGroup']          = 'SQL príkaz pre vyradenie používateľa z danej skupiny';
$lang['getGroupID']            = 'SQL príkaz pre získanie primárneho kľúča skupiny';
